@@ -1,4 +1,6 @@
+from fixtup.entity.fixture_template import FixtureTemplate
 from fixtup.entity.plugin import Plugin
+from fixtup.hook.base import HookEvent
 
 
 class FixtupException(Exception):
@@ -35,3 +37,10 @@ class PluginRuntimeError(FixtupException):
     def __init__(self, msg: str, plugin: Plugin):
         msg = f'{msg} - plugin: {plugin.module_name}'
         super().__init__(msg)
+
+
+class HookRuntimeError(FixtupException):
+
+    def __init__(self, msg: str, template: FixtureTemplate,hook_event: HookEvent, hook_script: str):
+        msg = f'{msg} - fixture: {template.identifier}, hook: {hook_event}, hook_script: {hook_script}'
+        super().__init__(msg)
